#!/bin/sh

gettextize --force --copy --intl
aclocal
autoheader
automake --add-missing --copy
autoconf
